%define majver %(echo %version | cut -d. -f1-2)
%define glibver 2.%(echo %version | cut -d. -f2)
Name:          gobject-introspection
Version:       1.81.4
Release:       1mamba
Summary:       A convenient bridge between C and a runtime language and more
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://gi.readthedocs.io/en/latest/
Source:        https://download.gnome.org/sources/gobject-introspection/%{majver}/gobject-introspection-%{version}.tar.xz
Source1:       https://download.gnome.org/sources/glib/%{glibver}/glib-%{glibver}.0.tar.xz
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libffi-devel
BuildRequires: libglib-devel
## AUTOBUILDREQ-END
BuildRequires: python3-devel >= 3.11.5-3mamba
BuildRequires: python-mako-py3
BuildRequires: python-Markdown-py3

%description
It makes sense to build many kinds of applications using (at least) two different levels and languages. Those being C+GObject, and a managed (GC'd) runtime. C is good for graphics, multimedia, and lower level systems work. However, writing complex software is difficult and error-prone without garbage collection. A managed runtime such as JavaScript, Python, Java, Lua, .NET, Scheme etc. makes a lot of sense for non-fast-path application logic such as configuration, layout, dialogs, etc.
Thus, one of the major goals of the GObject introspection project is to be a convenient bridge between these two worlds, and allow you to choose the right tool for the job, rather than being limited inside one or the other. With the introspection project, you can write for example a ClutterActor or GtkWidget subclass in C, and then without any additional work use that class inside JavaScript. 

%package devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
It makes sense to build many kinds of applications using (at least) two different levels and languages. Those being C+GObject, and a managed (GC'd) runtime. C is good for graphics, multimedia, and lower level systems work. However, writing complex software is difficult and error-prone without garbage collection. A managed runtime such as JavaScript, Python, Java, Lua, .NET, Scheme etc. makes a lot of sense for non-fast-path application logic such as configuration, layout, dialogs, etc.
Thus, one of the major goals of the GObject introspection project is to be a convenient bridge between these two worlds, and allow you to choose the right tool for the job, rather than being limited inside one or the other. With the introspection project, you can write for example a ClutterActor or GtkWidget subclass in C, and then without any additional work use that class inside JavaScript. 
This package contains static libraries and header files need for development.

%package apidocs
Group:         Documentation
Summary:       %{name} API documentation
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      gtk-doc

%description apidocs
This package includes the %{name} API documentation.

%debug_package

%prep
%setup -q -a1

%build
%meson \
   -Dgtk_doc=true \
   -Dglib_src_dir=${PWD}/glib-%{glibver}.0 \
   -Ddoctool=enabled

%meson_build

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%meson_install

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/g-ir-*
%{_datadir}/gir-1.0/*.gir
%{_datadir}/gir-1.0/gir-*.rnc
%{_libdir}/girepository-1.0/*.typelib
%{_libdir}/libgirepository-1.0.so.*
%dir %{_libdir}/gobject-introspection
%dir %{_libdir}/gobject-introspection/giscanner
%{_libdir}/gobject-introspection/giscanner/*.py*
%dir %{_libdir}/gobject-introspection/giscanner/doctemplates
%{_libdir}/gobject-introspection/giscanner/doctemplates/*
%{_libdir}/gobject-introspection/giscanner/_giscanner.cpython-*.so
%{_mandir}/man1/g-ir-compiler.1*
%{_mandir}/man1/g-ir-doc-tool.1*
%{_mandir}/man1/g-ir-generate.1*
%{_mandir}/man1/g-ir-scanner.1*
%doc COPYING

%files devel
%defattr(-,root,root)
%{_libdir}/libgirepository-1.0.so
%dir %{_includedir}/gobject-introspection-1.0
%{_includedir}/gobject-introspection-1.0/*.h
%{_datadir}/gobject-introspection-1.0/Makefile.introspection
%{_datadir}/gobject-introspection-1.0/gdump.c
%{_datadir}/gobject-introspection-1.0/tests/
%{_datadir}/aclocal/introspection.m4
%{_libdir}/pkgconfig/*.pc
#%doc NEWS TODO

%files apidocs
%defattr(-,root,root)
%dir %{_datadir}/gtk-doc/html/gi
%{_datadir}/gtk-doc/html/gi/*

%changelog
* Sat Sep 07 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 1.81.4-1mamba
- update to 1.81.4

* Wed Apr 24 2024 Automatic Build System <autodist@openmamba.org> 1.80.1-1mamba
- automatic version update by autodist

* Sun Oct 01 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 1.78.1-2mamba
- rebuilt with python3 == 3.11

* Sat Sep 16 2023 Automatic Build System <autodist@mambasoft.it> 1.78.1-1mamba
- automatic version update by autodist

* Sun Sep 10 2023 Automatic Build System <autodist@mambasoft.it> 1.78.0-1mamba
- automatic version update by autodist

* Thu Mar 23 2023 Automatic Build System <autodist@mambasoft.it> 1.76.1-1mamba
- automatic version update by autodist

* Tue Mar 14 2023 Automatic Build System <autodist@mambasoft.it> 1.76.0-1mamba
- automatic version update by autodist

* Tue Nov 08 2022 Automatic Build System <autodist@mambasoft.it> 1.74.0-1mamba
- automatic version update by autodist

* Sat Mar 19 2022 Automatic Build System <autodist@mambasoft.it> 1.72.0-1mamba
- automatic version update by autodist

* Mon Oct 04 2021 Automatic Build System <autodist@mambasoft.it> 1.70.0-1mamba
- automatic version update by autodist

* Sat Mar 20 2021 Automatic Build System <autodist@mambasoft.it> 1.68.0-1mamba
- automatic version update by autodist

* Thu Oct 22 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.66.1-2mamba
- rebuilt with glib sources needed to add docs to gir (fixes glibd build)

* Sat Oct 03 2020 Automatic Build System <autodist@mambasoft.it> 1.66.1-1mamba
- automatic version update by autodist

* Fri Sep 18 2020 Automatic Build System <autodist@mambasoft.it> 1.66.0-1mamba
- automatic version update by autodist

* Mon Apr 06 2020 Automatic Build System <autodist@mambasoft.it> 1.64.1-1mamba
- automatic version update by autodist

* Sun Mar 08 2020 Automatic Build System <autodist@mambasoft.it> 1.64.0-1mamba
- automatic version update by autodist

* Sat Oct 05 2019 Automatic Build System <autodist@mambasoft.it> 1.62.0-1mamba
- automatic version update by autodist

* Sat Jul 06 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.60.2-1mamba
- update to 1.60.2

* Sun Aug 12 2018 Automatic Build System <autodist@mambasoft.it> 1.56.1-1mamba
- automatic version update by autodist

* Thu Oct 13 2016 Automatic Build System <autodist@mambasoft.it> 1.50.0-1mamba
- automatic version update by autodist

* Mon May 02 2016 Automatic Build System <autodist@mambasoft.it> 1.48.0-1mamba
- automatic version update by autodist

* Sat Nov 14 2015 Automatic Build System <autodist@mambasoft.it> 1.46.0-1mamba
- automatic version update by autodist

* Tue Apr 21 2015 Automatic Build System <autodist@mambasoft.it> 1.44.0-1mamba
- automatic version update by autodist

* Tue Sep 23 2014 Automatic Build System <autodist@mambasoft.it> 1.42.0-1mamba
- automatic version update by autodist

* Fri Sep 19 2014 Automatic Build System <autodist@mambasoft.it> 1.41.91-1mamba
- automatic update by autodist

* Tue Jul 22 2014 Automatic Build System <autodist@mambasoft.it> 1.41.4-1mamba
- automatic version update by autodist

* Wed Jun 25 2014 Automatic Build System <autodist@mambasoft.it> 1.41.3-1mamba
- automatic version update by autodist

* Fri May 02 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.40.0-2mamba
- x86_64: add python-mako build requirement to build g-ir-doc-tool

* Wed Mar 26 2014 Automatic Build System <autodist@mambasoft.it> 1.40.0-1mamba
- automatic version update by autodist

* Mon Oct 07 2013 Automatic Build System <autodist@mambasoft.it> 1.38.0-1mamba
- automatic version update by autodist

* Sun May 26 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.36.0-2mamba
- rebuilt with python 2.7

* Fri Mar 29 2013 Automatic Build System <autodist@mambasoft.it> 1.36.0-1mamba
- automatic version update by autodist

* Mon Nov 12 2012 Automatic Build System <autodist@mambasoft.it> 1.34.2-1mamba
- automatic version update by autodist

* Thu Oct 18 2012 Automatic Build System <autodist@mambasoft.it> 1.34.1.1-1mamba
- automatic version update by autodist

* Wed Sep 26 2012 Automatic Build System <autodist@mambasoft.it> 1.34.0-1mamba
- automatic version update by autodist

* Tue Apr 17 2012 Automatic Build System <autodist@mambasoft.it> 1.32.1-1mamba
- automatic version update by autodist

* Sun Apr 01 2012 Automatic Build System <autodist@mambasoft.it> 1.32.0-1mamba
- update to 1.32.0

* Wed Oct 26 2011 Automatic Build System <autodist@mambasoft.it> 1.31.0-1mamba
- automatic version update by autodist

* Mon Oct 03 2011 Automatic Build System <autodist@mambasoft.it> 1.30.0-1mamba
- automatic version update by autodist

* Tue May 03 2011 Automatic Build System <autodist@mambasoft.it> 0.10.8-1mamba
- automatic update by autodist

* Mon Apr 04 2011 Automatic Build System <autodist@mambasoft.it> 0.10.7-1mamba
- automatic update by autodist

* Sat Mar 26 2011 Automatic Build System <autodist@mambasoft.it> 0.10.6-1mamba
- automatic update by autodist

* Sat Mar 26 2011 Automatic Build System <autodist@mambasoft.it> 0.10.5-1mamba
- automatic update by autodist

* Thu Mar 10 2011 Automatic Build System <autodist@mambasoft.it> 0.10.4-1mamba
- automatic update by autodist

* Wed Feb 23 2011 Automatic Build System <autodist@mambasoft.it> 0.10.3-1mamba
- automatic update by autodist

* Mon Feb 07 2011 Automatic Build System <autodist@mambasoft.it> 0.10.2-1mamba
- automatic update by autodist

* Wed Jan 12 2011 Automatic Build System <autodist@mambasoft.it> 0.10.1-1mamba
- automatic update by autodist

* Thu Dec 23 2010 Automatic Build System <autodist@mambasoft.it> 0.10.0-1mamba
- automatic update to 0.10.0 by autodist

* Wed Oct 13 2010 Automatic Build System <autodist@mambasoft.it> 0.9.12-1mamba
- update to 0.9.12

* Mon Oct 04 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.10-1mamba
- update to 0.9.10

* Sat Sep 25 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.3-2mamba
- rebuilt with libffi 3.0.9

* Tue Aug 17 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.3-1mamba
- update to 0.9.3

* Mon Jun 28 2010 Automatic Build System <autodist@mambasoft.it> 0.6.14-1mamba
- automatic update by autodist

* Sat May 22 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.11-1mamba
- update to 0.6.11

* Tue Sep 29 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.5-1mamba
- package created by autospec
